@@ -16,6 +16,7 @@ from . import settings
 from . import tokens
 from . import translations
 from . import views
+from .translations import get_translations
 
 # Enable the following: from flask.ext.user import current_user
 from flask_login import current_user
@@ -23,7 +24,7 @@ from flask_login import current_user
 # Enable the following: from flask.ext.user import login_required, roles_required
 from .decorators import *
 
-__version__ = '0.6'
+__version__ = '0.6.1'
 
 def _flask_user_context_processor():
     """ Make 'user_manager' available to Jinja2 templates"""
@@ -66,6 +67,7 @@ class UserManager(object):
                 password_crypt_context=None,
                 send_email_function = emails.send_email,
                 token_manager=tokens.TokenManager(),
+                legacy_check_password_hash=None
                 ):
         """ Initialize the UserManager with custom or built-in attributes"""
         self.db_adapter = db_adapter
@@ -102,6 +104,7 @@ class UserManager(object):
         self.token_manager = token_manager
         self.password_crypt_context = password_crypt_context
         self.send_email_function = send_email_function
+        self.legacy_check_password_hash = legacy_check_password_hash
 
         self.app = app
         if app:
@@ -125,8 +128,8 @@ class UserManager(object):
         # Initialize Translations -- Only if Flask-Babel has been installed
         if hasattr(app.jinja_env, 'install_gettext_callables'):
             app.jinja_env.install_gettext_callables(
-                    translations.gettext,
-                    translations.ngettext,
+                    lambda x: get_translations().ugettext(x),
+                    lambda s, p, n: get_translations().ungettext(s, p, n),
                     newstyle=True)
         else:
             app.jinja_env.add_extension('jinja2.ext.i18n')
@@ -211,8 +214,43 @@ class UserManager(object):
     def hash_password(self, password):
         return passwords.hash_password(self, password)
 
-    def verify_password(self, password, hashed_password):
-        return passwords.verify_password(self, password, hashed_password)
+    def get_password(self, user):
+        use_auth_class = True if self.db_adapter.UserAuthClass and hasattr(user, 'user_auth') else False
+        # Handle v0.5 backward compatibility
+        if self.db_adapter.UserProfileClass:
+            hashed_password = user.password
+        else:
+            hashed_password = user.user_auth.password if use_auth_class else user.password
+        return hashed_password
+
+    def update_password(self, user, hashed_password):
+        use_auth_class = True if self.db_adapter.UserAuthClass and hasattr(user, 'user_auth') else False
+
+        if use_auth_class:
+            user.user_auth.password = hashed_password
+        else:
+            user.password = hashed_password
+        self.db_adapter.commit()
+
+    def verify_password(self, password, user):
+        """
+        Make it backward compatible to legacy password hash.
+        In addition, if such password were found, update the user's password field.
+        """
+        verified = False
+        hashed_password = self.get_password(user)
+
+        try:
+            verified = passwords.verify_password(self, password, hashed_password)
+        except ValueError:
+            legacy_check = self.legacy_check_password_hash
+            if legacy_check:
+                verified = legacy_check(hashed_password, password)
+                if verified:
+                    # update the hash
+                    new_hash = self.hash_password(password)
+                    self.update_password(user, new_hash)
+        return verified
 
     def generate_token(self, user_id):
         return self.token_manager.generate_token(user_id)
