@@ -101,8 +101,7 @@ class ChangePasswordForm(Form):
             return False
 
         # Verify current_user and current_password
-        current_password = current_user.user_auth.password if user_manager.db_adapter.UserAuthClass and hasattr(current_user, 'user_auth') else current_user.password
-        if not current_user or not user_manager.verify_password(self.old_password.data, current_password):
+        if not current_user or not user_manager.verify_password(self.old_password.data, current_user):
             self.old_password.errors.append(_('Old Password is incorrect'))
             return False
 
@@ -136,8 +135,7 @@ class ChangeUsernameForm(Form):
             return False
 
         # Verify current_user and current_password
-        current_password = current_user.user_auth.password if user_manager.db_adapter.UserAuthClass and hasattr(current_user, 'user_auth') else current_user.password
-        if not current_user or not user_manager.verify_password(self.old_password.data, current_password):
+        if not current_user or not user_manager.verify_password(self.old_password.data, current_user):
             self.old_password.errors.append(_('Old Password is incorrect'))
             return False
 
@@ -145,9 +143,9 @@ class ChangeUsernameForm(Form):
         return True
 
 class ForgotPasswordForm(Form):
-    email = StringField(_('Email'), validators=[
-        validators.Required(_('Email is required')),
-        validators.Email(_('Invalid Email')),
+    email = StringField(_('Your email address'), validators=[
+        validators.Required(_('Email address is required')),
+        validators.Email(_('Invalid Email address')),
         ])
     submit = SubmitField(_('Send reset password email'))
 
@@ -204,21 +202,15 @@ class LoginForm(Form):
             user, user_email = user_manager.find_user_by_email(self.email.data)
 
         # Handle successful authentication
-        if user:
-            # Handle v0.5 backward compatibility
-            if user_manager.db_adapter.UserProfileClass:
-                current_password = user.password
-            else:
-                current_password = user.user_auth.password if user_manager.db_adapter.UserAuthClass else user.password
-            if user_manager.verify_password(self.password.data, current_password):
-                return True                         # Successful authentication
+        if user and user_manager.verify_password(self.password.data, user):
+            return True                         # Successful authentication
 
         # Handle unsuccessful authentication
         if user_manager.enable_username:
             if user_manager.enable_email:
                 self.username.errors.append(_('Incorrect Username/Email and Password'))
             else:
-                self.email.errors.append(_('Incorrect Username and Password'))
+                self.username.errors.append(_('Incorrect Username and Password'))
         else:
             self.email.errors.append(_('Incorrect Email and Password'))
         self.password.errors.append('')
@@ -276,9 +268,9 @@ class RegisterForm(Form):
         return True
 
 class ResendConfirmEmailForm(Form):
-    email = StringField(_('Email'), validators=[
-        validators.Required(_('Email is required')),
-        validators.Email(_('Invalid Email')),
+    email = StringField(_('Your email address'), validators=[
+        validators.Required(_('Email address is required')),
+        validators.Email(_('Invalid Email address')),
         ])
     submit = SubmitField(_('Resend email confirmation email'))
 
