@@ -43,7 +43,8 @@ def get_translations():
         flask_user_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'translations')
         ctx.flask_user_translations = support.Translations.load(flask_user_dir, locales, domain=domain)
 
-    return ctx.flask_user_translations
+    from flask.ext import babel
+    return ctx.flask_user_translations.merge(babel.get_translations())
 
 def gettext(string, **variables):
     """ Translate specified string."""
